@@ -5,25 +5,11 @@
  * Date        : 2007-09-13
  * Description : Sane interface for KDE
  *
- * Copyright (C) 2007-2008 by Kare Sars <kare dot sars at iki dot fi>
- * Copyright (C) 2007-2008 by Gilles Caulier <caulier dot gilles at gmail dot com>
- * Copyright (C) 2014 by Gregor Mitsch: port to KDE5 frameworks
+ * SPDX-FileCopyrightText: 2007-2008 Kare Sars <kare dot sars at iki dot fi>
+ * SPDX-FileCopyrightText: 2007-2008 Gilles Caulier <caulier dot gilles at gmail dot com>
+ * SPDX-FileCopyrightText: 2014 Gregor Mitsch : port to KDE5 frameworks
  *
- * This library is free software; you can redistribute it and/or
- * modify it under the terms of the GNU Lesser General Public
- * License as published by the Free Software Foundation; either
- * version 2.1 of the License, or (at your option) version 3, or any
- * later version accepted by the membership of KDE e.V. (or its
- * successor approved by the membership of KDE e.V.), which shall
- * act as a proxy defined in Section 6 of version 3 of the license.
- *
- * This library is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- * Lesser General Public License for more details.
- *
- * You should have received a copy of the GNU Lesser General Public
- * License along with this program.  If not, see <http://www.gnu.org/licenses/>.
+ * SPDX-License-Identifier: LGPL-2.1-only OR LGPL-3.0-only OR LicenseRef-KDE-Accepted-LGPL
  *
  * ============================================================ */
 
@@ -163,21 +149,20 @@ void KSaneWidgetPrivate::clearDeviceOptions()
     m_scanThread = nullptr;
 
     m_devName.clear();
+    m_model.clear();
+    m_vendor.clear();
+    Q_EMIT q->openedDeviceInfoUpdated(m_devName, m_vendor, m_model);
 }
 
 void KSaneWidgetPrivate::devListUpdated()
 {
     if (m_vendor.isEmpty()) {
-        const QList<KSaneWidget::DeviceInfo> list = m_findDevThread->devicesList();
-        if (list.size() == 0) {
-            return;
-        }
-        for (int i = 0; i < list.size(); ++i) {
-            const KSaneWidget::DeviceInfo info = list.at(i);
-            qCDebug(KSANE_LOG) << info.name;
-            if (info.name == m_devName) {
-                m_vendor    = info.vendor;
-                m_model     = info.model;
+        const QList<KSaneWidget::DeviceInfo> deviceList = m_findDevThread->devicesList();
+        for (const auto &device : deviceList) {
+            if (device.name == m_devName) {
+                m_vendor    = device.vendor;
+                m_model     = device.model;
+                Q_EMIT q->openedDeviceInfoUpdated(m_devName, m_vendor, m_model);
                 break;
             }
         }
@@ -186,7 +171,7 @@ void KSaneWidgetPrivate::devListUpdated()
 
 void KSaneWidgetPrivate::signalDevListUpdate()
 {
-    emit q->availableDevices(m_findDevThread->devicesList());
+    Q_EMIT q->availableDevices(m_findDevThread->devicesList());
 }
 
 KSaneWidget::ImageFormat KSaneWidgetPrivate::getImgFormat(SANE_Parameters &params)
@@ -1057,7 +1042,7 @@ void KSaneWidgetPrivate::previewScanDone()
         sane_close(m_saneHandle);
         m_saneHandle = nullptr;
         clearDeviceOptions();
-        emit q->scanDone(KSaneWidget::NoError, QString());
+        Q_EMIT q->scanDone(KSaneWidget::NoError, QString());
         return;
     }
 
@@ -1092,7 +1077,7 @@ void KSaneWidgetPrivate::previewScanDone()
     m_scanOngoing = false;
     m_updProgressTmr.stop();
 
-    emit q->scanDone(KSaneWidget::NoError, QString());
+    Q_EMIT q->scanDone(KSaneWidget::NoError, QString());
 
     return;
 }
@@ -1171,7 +1156,7 @@ void KSaneWidgetPrivate::oneFinalScanDone()
             int bytesPerLine = qMax(getBytesPerLines(params), 1); // ensure no div by 0
             lines = m_scanData.size() / bytesPerLine;
         }
-        emit q->imageReady(m_scanData,
+        Q_EMIT q->imageReady(m_scanData,
                            params.pixels_per_line,
                            lines,
                            getBytesPerLines(params),
@@ -1241,7 +1226,7 @@ void KSaneWidgetPrivate::oneFinalScanDone()
                 }
             }
         }
-        emit q->scanDone(KSaneWidget::NoError, QString());
+        Q_EMIT q->scanDone(KSaneWidget::NoError, QString());
     } else {
         switch (m_scanThread->saneStatus()) {
         case SANE_STATUS_GOOD:
@@ -1249,7 +1234,7 @@ void KSaneWidgetPrivate::oneFinalScanDone()
         case SANE_STATUS_EOF:
             break;
         case SANE_STATUS_NO_DOCS:
-            emit q->scanDone(KSaneWidget::Information, sane_i18n(sane_strstatus(m_scanThread->saneStatus())));
+            Q_EMIT q->scanDone(KSaneWidget::Information, sane_i18n(sane_strstatus(m_scanThread->saneStatus())));
             alertUser(KSaneWidget::Information, sane_i18n(sane_strstatus(m_scanThread->saneStatus())));
             break;
         case SANE_STATUS_UNSUPPORTED:
@@ -1260,7 +1245,7 @@ void KSaneWidgetPrivate::oneFinalScanDone()
         case SANE_STATUS_COVER_OPEN:
         case SANE_STATUS_DEVICE_BUSY:
         case SANE_STATUS_ACCESS_DENIED:
-            emit q->scanDone(KSaneWidget::ErrorGeneral, sane_i18n(sane_strstatus(m_scanThread->saneStatus())));
+            Q_EMIT q->scanDone(KSaneWidget::ErrorGeneral, sane_i18n(sane_strstatus(m_scanThread->saneStatus())));
             alertUser(KSaneWidget::ErrorGeneral, sane_i18n(sane_strstatus(m_scanThread->saneStatus())));
             break;
         }
@@ -1281,7 +1266,7 @@ void KSaneWidgetPrivate::setBusy(bool busy)
         m_activityFrame->hide();
         m_btnFrame->hide();
         m_optionPollTmr.stop();
-        emit q->scanProgress(0);
+        Q_EMIT q->scanProgress(0);
     } else {
         m_warmingUp->hide();
         m_activityFrame->hide();
@@ -1289,7 +1274,7 @@ void KSaneWidgetPrivate::setBusy(bool busy)
         if (m_pollList.size() > 0) {
             m_optionPollTmr.start();
         }
-        emit q->scanProgress(100);
+        Q_EMIT q->scanProgress(100);
     }
 
     m_optsTabWidget->setDisabled(busy);
@@ -1361,7 +1346,7 @@ void KSaneWidgetPrivate::updateProgress()
     }
 
     m_progressBar->setValue(progress);
-    emit q->scanProgress(progress);
+    Q_EMIT q->scanProgress(progress);
 }
 
 void KSaneWidgetPrivate::alertUser(int type, const QString &strStatus)
@@ -1376,7 +1361,7 @@ void KSaneWidgetPrivate::alertUser(int type, const QString &strStatus)
             break;
         }
     } else {
-        emit q->userMessage(type, strStatus);
+        Q_EMIT q->userMessage(type, strStatus);
     }
 }
 
